@@ -46,10 +46,13 @@ class Phi():
     def inv_comp_phi(self, par, x):
         assert len(par) >= self.par_len * self.n, "Not enough parameters"
         inv_comp = copy.deepcopy(x)
-        inv_comp = self.inv_fn(par[-self.par_len:], inv_comp)
-        for i in range(1, self.n - 1):
-            inv_comp = self.inv_fn(
-                par[-self.par_len * (i + 1):-self.par_len * i], inv_comp)
+        for i in range(0, self.n):
+            print(i)
+            if i == 0:
+                inv_comp = self.inv_fn(par[-self.par_len:], inv_comp)
+            else:
+                inv_comp = self.inv_fn(
+                    par[-self.par_len * (i + 1):-self.par_len * i], inv_comp)
         return inv_comp
 
     def likelihood(self, par):
